@@ -1,8 +1,15 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
+
+<!--
+SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+
+SPDX-License-Identifier: LGPL-3.0-or-later
+-->
+
 <context>
     <name>DAboutDialog</name>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1405"/>
+        <location filename="../widgets/dapplication.cpp" line="1421"/>
         <source>%1 is released under %2</source>
         <translation>%1ཡིས་%2ཡི་གྲོས་དོན་བརྩི་སྲུང་བྱས་ནས་ཁྱབ་བསྒྲགས་བྱ་རྒྱུ།</translation>
     </message>
@@ -704,14 +711,15 @@
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="129"/>
-        <location filename="../widgets/daboutdialog.cpp" line="138"/>
+        <location filename="../widgets/daboutdialog.cpp" line="395"/>
+        <location filename="../widgets/daboutdialog.cpp" line="400"/>
         <source>Sincerely appreciate the open-source software used.</source>
-        <translation>སྤྱོད་བཞིན་པའི་སྒོ་འབྱེད་མཉེན་ཆས་ལ་བཀའ་དྲིན་ཆེ་ཞུ།</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../widgets/daboutdialog.cpp" line="140"/>
+        <location filename="../widgets/daboutdialog.cpp" line="396"/>
         <source>open-source software</source>
-        <translation>སྒོ་འབྱེད་མཉེན་ཆས་</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/dfeaturedisplaydialog.cpp" line="151"/>
@@ -724,9 +732,9 @@
         <translation>དེ་བས་མང་བར་རྒྱུས་ལོན།</translation>
     </message>
     <message>
-        <location filename="../widgets/dlicensedialog.cpp" line="141"/>
-        <source>Open-Source Software</source>
-        <translation>སྒོ་འབྱེད་མཉེན་ཆས།</translation>
+        <location filename="../widgets/dlicensedialog.cpp" line="74"/>
+        <source>Credits</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -780,7 +788,7 @@
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="683"/>
         <source>Custom toolbar</source>
-        <translation>རང་འཇོག་ཡོ་བྱད་བསྟར་བྱང་།</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="691"/>
