@@ -1,8 +1,15 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
+
+<!--
+SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+
+SPDX-License-Identifier: LGPL-3.0-or-later
+-->
+
 <context>
     <name>DAboutDialog</name>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1405"/>
+        <location filename="../widgets/dapplication.cpp" line="1421"/>
         <source>%1 is released under %2</source>
         <translation>%1 está lanzado bajo %2</translation>
     </message>
@@ -113,7 +120,7 @@
     <message>
         <location filename="../widgets/dkeysequenceedit.cpp" line="97"/>
         <source>Enter a new shortcut</source>
-        <translation>Introducir un nuevo acceso directo</translation>
+        <translation>Introducir un nuevo atajo</translation>
     </message>
 </context>
 <context>
@@ -577,7 +584,7 @@
     <message>
         <location filename="../widgets/dsettingswidgetfactory.cpp" line="68"/>
         <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
-        <translation>Este acceso directo tiene conflicto con %1, haga clic en Añadir para que este atajo sea efectivo inmediatamente.</translation>
+        <translation>Este atajo tiene conflicto con %1, haga clic en Añadir para que este atajo sea efectivo inmediatamente.</translation>
     </message>
 </context>
 <context>
@@ -704,12 +711,13 @@
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="129"/>
-        <location filename="../widgets/daboutdialog.cpp" line="138"/>
+        <location filename="../widgets/daboutdialog.cpp" line="395"/>
+        <location filename="../widgets/daboutdialog.cpp" line="400"/>
         <source>Sincerely appreciate the open-source software used.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../widgets/daboutdialog.cpp" line="140"/>
+        <location filename="../widgets/daboutdialog.cpp" line="396"/>
         <source>open-source software</source>
         <translation type="unfinished"/>
     </message>
@@ -724,8 +732,8 @@
         <translation>Saber más</translation>
     </message>
     <message>
-        <location filename="../widgets/dlicensedialog.cpp" line="141"/>
-        <source>Open-Source Software</source>
+        <location filename="../widgets/dlicensedialog.cpp" line="74"/>
+        <source>Credits</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -750,7 +758,7 @@
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="634"/>
         <source>Theme</source>
-        <translation>tema</translation>
+        <translation>Tema</translation>
     </message>
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="636"/>
