@@ -1,8 +1,15 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
+
+<!--
+SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+
+SPDX-License-Identifier: LGPL-3.0-or-later
+-->
+
 <context>
     <name>DAboutDialog</name>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1405"/>
+        <location filename="../widgets/dapplication.cpp" line="1421"/>
         <source>%1 is released under %2</source>
         <translation>%1 est publié sous %2</translation>
     </message>
@@ -559,7 +566,7 @@
     <message>
         <location filename="../widgets/dsearchedit.cpp" line="286"/>
         <source>Search</source>
-        <translation>Chercher</translation>
+        <translation>Rechercher</translation>
     </message>
 </context>
 <context>
@@ -670,7 +677,7 @@
     <message>
         <location filename="../widgets/dsimplelistview.cpp" line="1347"/>
         <source>No search result</source>
-        <translation>Aucun résultat de recherche</translation>
+        <translation>Aucun résultat trouvé</translation>
     </message>
     <message>
         <location filename="../widgets/private/settings/content.cpp" line="330"/>
@@ -704,12 +711,13 @@
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="129"/>
-        <location filename="../widgets/daboutdialog.cpp" line="138"/>
+        <location filename="../widgets/daboutdialog.cpp" line="395"/>
+        <location filename="../widgets/daboutdialog.cpp" line="400"/>
         <source>Sincerely appreciate the open-source software used.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../widgets/daboutdialog.cpp" line="140"/>
+        <location filename="../widgets/daboutdialog.cpp" line="396"/>
         <source>open-source software</source>
         <translation type="unfinished"/>
     </message>
@@ -724,8 +732,8 @@
         <translation>En apprendre plus</translation>
     </message>
     <message>
-        <location filename="../widgets/dlicensedialog.cpp" line="141"/>
-        <source>Open-Source Software</source>
+        <location filename="../widgets/dlicensedialog.cpp" line="74"/>
+        <source>Credits</source>
         <translation type="unfinished"/>
     </message>
 </context>
