@@ -1,8 +1,15 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
+
+<!--
+SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+
+SPDX-License-Identifier: LGPL-3.0-or-later
+-->
+
 <context>
     <name>DAboutDialog</name>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1405"/>
+        <location filename="../widgets/dapplication.cpp" line="1421"/>
         <source>%1 is released under %2</source>
         <translation>%1 is uitgebracht onder de %2</translation>
     </message>
@@ -105,7 +112,7 @@
     <message>
         <location filename="../widgets/dinputdialog.cpp" line="30"/>
         <source>Confirm</source>
-        <translation>Bevestigen</translation>
+        <translation>Oké</translation>
     </message>
 </context>
 <context>
@@ -704,12 +711,13 @@
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="129"/>
-        <location filename="../widgets/daboutdialog.cpp" line="138"/>
+        <location filename="../widgets/daboutdialog.cpp" line="395"/>
+        <location filename="../widgets/daboutdialog.cpp" line="400"/>
         <source>Sincerely appreciate the open-source software used.</source>
         <translation>Maak dankbaar gebruik van opensourcesoftware.</translation>
     </message>
     <message>
-        <location filename="../widgets/daboutdialog.cpp" line="140"/>
+        <location filename="../widgets/daboutdialog.cpp" line="396"/>
         <source>open-source software</source>
         <translation>opensourcesoftware</translation>
     </message>
@@ -724,9 +732,9 @@
         <translation>Meer informatie</translation>
     </message>
     <message>
-        <location filename="../widgets/dlicensedialog.cpp" line="141"/>
-        <source>Open-Source Software</source>
-        <translation>Opensourcesoftware</translation>
+        <location filename="../widgets/dlicensedialog.cpp" line="74"/>
+        <source>Credits</source>
+        <translation>Met dank aan</translation>
     </message>
 </context>
 <context>
