@@ -1,8 +1,15 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
+
+<!--
+SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+
+SPDX-License-Identifier: LGPL-3.0-or-later
+-->
+
 <context>
     <name>DAboutDialog</name>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1405"/>
+        <location filename="../widgets/dapplication.cpp" line="1421"/>
         <source>%1 is released under %2</source>
         <translation>%1 выпущен под %2</translation>
     </message>
@@ -22,7 +29,7 @@
     <message>
         <location filename="../widgets/dcrumbedit.cpp" line="875"/>
         <source>Dark Gray</source>
-        <translation>Темно-серый</translation>
+        <translation>Темно-Серый</translation>
     </message>
     <message>
         <location filename="../widgets/dcrumbedit.cpp" line="878"/>
@@ -32,7 +39,7 @@
     <message>
         <location filename="../widgets/dcrumbedit.cpp" line="881"/>
         <source>Light Gray</source>
-        <translation>Светло-серый</translation>
+        <translation>Светло-Серый</translation>
     </message>
     <message>
         <location filename="../widgets/dcrumbedit.cpp" line="884"/>
@@ -67,32 +74,32 @@
     <message>
         <location filename="../widgets/dcrumbedit.cpp" line="902"/>
         <source>Dark Red</source>
-        <translation>Темно-красный</translation>
+        <translation>Темно-Красный</translation>
     </message>
     <message>
         <location filename="../widgets/dcrumbedit.cpp" line="905"/>
         <source>Dark Green</source>
-        <translation>Темно-зеленый</translation>
+        <translation>Темно-Зеленый</translation>
     </message>
     <message>
         <location filename="../widgets/dcrumbedit.cpp" line="908"/>
         <source>Dark Blue</source>
-        <translation>Темно-синий</translation>
+        <translation>Темно-Синий</translation>
     </message>
     <message>
         <location filename="../widgets/dcrumbedit.cpp" line="911"/>
         <source>Dark Cyan</source>
-        <translation>Темно-голубой</translation>
+        <translation>Темно-Голубой</translation>
     </message>
     <message>
         <location filename="../widgets/dcrumbedit.cpp" line="914"/>
         <source>Dark Magenta</source>
-        <translation>Темно-пурпурный</translation>
+        <translation>Темно-Пурпурный</translation>
     </message>
     <message>
         <location filename="../widgets/dcrumbedit.cpp" line="917"/>
         <source>Dark Yellow</source>
-        <translation>Темно-желтый</translation>
+        <translation>Темно-Желтый</translation>
     </message>
 </context>
 <context>
@@ -203,12 +210,12 @@
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="422"/>
         <source>Portrait</source>
-        <translation>Книжная</translation>
+        <translation>Портрет</translation>
     </message>
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="432"/>
         <source>Landscape</source>
-        <translation>Альбомная</translation>
+        <translation>Ландшафт</translation>
     </message>
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="460"/>
@@ -309,7 +316,7 @@
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="641"/>
         <source>Print Layout</source>
-        <translation>Макет печати</translation>
+        <translation>Макет Печати</translation>
     </message>
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
@@ -369,12 +376,12 @@
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
         <source>Front to back</source>
-        <translation>От лицевой к задней</translation>
+        <translation>С лицевой стороны обратно</translation>
     </message>
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
         <source>Back to front</source>
-        <translation> От задней к лицевой</translation>
+        <translation> С обратной стороны на лицевую</translation>
     </message>
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="774"/>
@@ -520,7 +527,7 @@
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="2312"/>
         <source>Save as PDF</source>
-        <translation>Сохранить как PDF</translation>
+        <translation>Сохранить в PDF</translation>
     </message>
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="2351"/>
@@ -675,7 +682,7 @@
     <message>
         <location filename="../widgets/private/settings/content.cpp" line="330"/>
         <source>Restore Defaults</source>
-        <translation>Восстановить значения по умолчанию</translation>
+        <translation>Восстановить значения По-умолчанию</translation>
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="109"/>
@@ -704,12 +711,13 @@
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="129"/>
-        <location filename="../widgets/daboutdialog.cpp" line="138"/>
+        <location filename="../widgets/daboutdialog.cpp" line="395"/>
+        <location filename="../widgets/daboutdialog.cpp" line="400"/>
         <source>Sincerely appreciate the open-source software used.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../widgets/daboutdialog.cpp" line="140"/>
+        <location filename="../widgets/daboutdialog.cpp" line="396"/>
         <source>open-source software</source>
         <translation type="unfinished"/>
     </message>
@@ -724,8 +732,8 @@
         <translation>Узнать больше</translation>
     </message>
     <message>
-        <location filename="../widgets/dlicensedialog.cpp" line="141"/>
-        <source>Open-Source Software</source>
+        <location filename="../widgets/dlicensedialog.cpp" line="74"/>
+        <source>Credits</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -755,17 +763,17 @@
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="636"/>
         <source>Light Theme</source>
-        <translation>Светлая тема</translation>
+        <translation>Светлая Тема</translation>
     </message>
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="637"/>
         <source>Dark Theme</source>
-        <translation>Темная тема</translation>
+        <translation>Темная Тема</translation>
     </message>
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="638"/>
         <source>System Theme</source>
-        <translation>Тема системы</translation>
+        <translation>Тема Системы</translation>
     </message>
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="668"/>
