@@ -1,8 +1,15 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
+
+<!--
+SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+
+SPDX-License-Identifier: LGPL-3.0-or-later
+-->
+
 <context>
     <name>DAboutDialog</name>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1405"/>
+        <location filename="../widgets/dapplication.cpp" line="1421"/>
         <source>%1 is released under %2</source>
         <translation>%1 je izdana pod %2</translation>
     </message>
@@ -621,17 +628,17 @@
     <message>
         <location filename="../widgets/private/dtitlebareditpanel.cpp" line="884"/>
         <source>Default toolset</source>
-        <translation>Priveti nabor orodji</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/private/dtitlebareditpanel.cpp" line="915"/>
         <source>Drag your favorite items into the toolbar</source>
-        <translation>Povlecite priljubljene predmete v orodno vrstico</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/private/dtitlebareditpanel.cpp" line="916"/>
         <source>Drag below items into the toolbar to restore defaults</source>
-        <translation>Povlecite spodnje predmete v orodno vrstico, da povrnite privzeto</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/private/dtitlebareditpanel.cpp" line="921"/>
@@ -652,12 +659,12 @@
     <message>
         <location filename="../widgets/dlineedit.cpp" line="526"/>
         <source>&amp;Copy</source>
-        <translation>&amp;Kopiraj</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/dlineedit.cpp" line="529"/>
         <source>Cu&amp;t</source>
-        <translation>&amp;Izrezi</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/dlineedit.cpp" line="534"/>
@@ -680,22 +687,22 @@
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="109"/>
         <source>Version</source>
-        <translation>Različica</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="111"/>
         <source>Features</source>
-        <translation>Zmožnosti</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="123"/>
         <source>Homepage</source>
-        <translation>Domača stran</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="125"/>
         <source>Description</source>
-        <translation>Opis</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="127"/>
@@ -704,29 +711,30 @@
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="129"/>
-        <location filename="../widgets/daboutdialog.cpp" line="138"/>
+        <location filename="../widgets/daboutdialog.cpp" line="395"/>
+        <location filename="../widgets/daboutdialog.cpp" line="400"/>
         <source>Sincerely appreciate the open-source software used.</source>
-        <translation>Spoštujte odprtokodni program, ki ga uporabljate.</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../widgets/daboutdialog.cpp" line="140"/>
+        <location filename="../widgets/daboutdialog.cpp" line="396"/>
         <source>open-source software</source>
-        <translation>odprtkodni program</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/dfeaturedisplaydialog.cpp" line="151"/>
         <source>Continue</source>
-        <translation>Nadaljuj</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/dfeaturedisplaydialog.cpp" line="175"/>
         <source>Learn More</source>
-        <translation>Več o tem</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../widgets/dlicensedialog.cpp" line="141"/>
-        <source>Open-Source Software</source>
-        <translation>Odprtkodni program</translation>
+        <location filename="../widgets/dlicensedialog.cpp" line="74"/>
+        <source>Credits</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -775,12 +783,12 @@
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="676"/>
         <source>Feedback</source>
-        <translation>Odziv</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="683"/>
         <source>Custom toolbar</source>
-        <translation>Orodna vrstica po meri</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="691"/>
