@@ -1,8 +1,15 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
+
+<!--
+SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+
+SPDX-License-Identifier: LGPL-3.0-or-later
+-->
+
 <context>
     <name>DAboutDialog</name>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1405"/>
+        <location filename="../widgets/dapplication.cpp" line="1421"/>
         <source>%1 is released under %2</source>
         <translation>%1 قۇيۇپ بېرىش ئاستىداi %2</translation>
     </message>
@@ -704,14 +711,15 @@
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="129"/>
-        <location filename="../widgets/daboutdialog.cpp" line="138"/>
+        <location filename="../widgets/daboutdialog.cpp" line="395"/>
+        <location filename="../widgets/daboutdialog.cpp" line="400"/>
         <source>Sincerely appreciate the open-source software used.</source>
-        <translation>ئىشلەتكەن ئوچۇق كودلۇق يۇمشاق دېتاللارغا رەھمەت ئېيتىمىز</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../widgets/daboutdialog.cpp" line="140"/>
+        <location filename="../widgets/daboutdialog.cpp" line="396"/>
         <source>open-source software</source>
-        <translation>ئوچۇق كودلۇق يۇمشاق دېتال</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/dfeaturedisplaydialog.cpp" line="151"/>
@@ -724,9 +732,9 @@
         <translation>تېخىمۇ كۆپ چۈشىنىش</translation>
     </message>
     <message>
-        <location filename="../widgets/dlicensedialog.cpp" line="141"/>
-        <source>Open-Source Software</source>
-        <translation>ئوچۇق كودلۇق يۇمشاق دېتال</translation>
+        <location filename="../widgets/dlicensedialog.cpp" line="74"/>
+        <source>Credits</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -780,7 +788,7 @@
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="683"/>
         <source>Custom toolbar</source>
-        <translation>قورال ئىستونى بەلگىلەش</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../widgets/dtitlebar.cpp" line="691"/>
