@@ -1,8 +1,15 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
+
+<!--
+SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+
+SPDX-License-Identifier: LGPL-3.0-or-later
+-->
+
 <context>
     <name>DAboutDialog</name>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1405"/>
+        <location filename="../widgets/dapplication.cpp" line="1421"/>
         <source>%1 is released under %2</source>
         <translation>%1遵循%2協議發布</translation>
     </message>
@@ -227,7 +234,7 @@
         <location filename="../widgets/dprintpreviewdialog.cpp" line="1679"/>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="1694"/>
         <source>Color</source>
-        <translation>顏色</translation>
+        <translation>彩色</translation>
     </message>
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="475"/>
@@ -704,12 +711,13 @@
     </message>
     <message>
         <location filename="../widgets/daboutdialog.cpp" line="129"/>
-        <location filename="../widgets/daboutdialog.cpp" line="138"/>
+        <location filename="../widgets/daboutdialog.cpp" line="395"/>
+        <location filename="../widgets/daboutdialog.cpp" line="400"/>
         <source>Sincerely appreciate the open-source software used.</source>
         <translation>致謝所使用的開源軟體</translation>
     </message>
     <message>
-        <location filename="../widgets/daboutdialog.cpp" line="140"/>
+        <location filename="../widgets/daboutdialog.cpp" line="396"/>
         <source>open-source software</source>
         <translation>開源軟體</translation>
     </message>
@@ -724,9 +732,9 @@
         <translation>了解更多</translation>
     </message>
     <message>
-        <location filename="../widgets/dlicensedialog.cpp" line="141"/>
-        <source>Open-Source Software</source>
-        <translation>開源軟體</translation>
+        <location filename="../widgets/dlicensedialog.cpp" line="74"/>
+        <source>Credits</source>
+        <translation>許可</translation>
     </message>
 </context>
 <context>
@@ -793,4 +801,4 @@
         <translation>退出</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
