@@ -258,7 +258,7 @@ const QRect DArrowRectanglePrivate::currentScreenRect(const int x, const int y)
 {
     if (floatMode == DArrowRectangle::FloatWidget) {
         D_Q(DArrowRectangle);
-        if (q->windowType() == Qt::Widget && q->parentWidget()) {
+        if (q->parentWidget()) {
             return q->parentWidget()->rect();
         }
     }
