@@ -1,10 +1,11 @@
-// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2017 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dcrumbedit.h"
 #include "dobject_p.h"
 #include "DStyle"
+#include "dsizemode.h"
 
 #include <QAbstractTextDocumentLayout>
 #include <QPainter>
@@ -18,6 +19,8 @@
 #include <QJsonArray>
 #include <QTime>
 
+#include <private/qtextdocument_p.h>
+
 DWIDGET_BEGIN_NAMESPACE
 
 enum Background {
@@ -109,6 +112,30 @@ public:
     QBrush backgroundBrush(const QRect &rect, const QBrush &brush);
 };
 
+class DCrumbEditPanelFrame : public QWidget {
+    Q_OBJECT
+
+public:
+    explicit DCrumbEditPanelFrame(QWidget *parent = nullptr)
+        :QWidget(parent)
+    {
+        setFocusProxy(parent);
+    }
+
+protected:
+    void paintEvent(QPaintEvent *event) override;
+};
+
+void DCrumbEditPanelFrame::paintEvent(QPaintEvent *event)
+{
+    QPainter p(this);
+    QStyleOptionFrame panel;
+    panel.initFrom(parentWidget());
+    panel.rect = rect();
+    style()->drawPrimitive(QStyle::PE_PanelLineEdit, &panel, &p, parentWidget());
+    QWidget::paintEvent(event);
+}
+
 /*!
     \class Dtk::Widget::DCrumbTextFormat
     \inmodule dtkwidget
@@ -261,11 +288,14 @@ public:
         widgetLeft = new QWidget(qq);
         widgetRight = new QWidget(qq);
         crumbRadius = DStyle::pixelMetric(qq->style(), DStyle::PM_FrameRadius);
+        panelFrame = new DCrumbEditPanelFrame(qq);
+        panelFrame->stackUnder(qq->viewport());
 
         widgetTop->setAccessibleName("DCrumbEditTopWidget");
         widgetBottom->setAccessibleName("DCrumbEditBottomWidget");
         widgetLeft->setAccessibleName("DCrumbEditLeftWidget");
         widgetRight->setAccessibleName("DCrumbEditRightWidget");
+        panelFrame->setAccessibleName("DCrumbEditPanelFrame");
     }
 
     void registerHandler(QAbstractTextDocumentLayout *layout)
@@ -500,6 +530,7 @@ public:
     int objectType;
     bool crumbReadOnly = false;
     int crumbRadius = 2;
+    bool explicitCrumbRadius = false;
     QString splitter = ",";
     QStringList formatList;
     QMap<QString, DCrumbTextFormat> formats;
@@ -507,6 +538,7 @@ public:
     bool dualClickMakeCrumb = false;
     QString currentText;
     QBrush currentBrush;
+    DCrumbEditPanelFrame* panelFrame = nullptr;
 
 public:
     QWidget* widgetTop;
@@ -609,9 +641,13 @@ DCrumbEdit::DCrumbEdit(QWidget *parent)
 
     qsrand(QTime(0, 0, 0).secsTo(QTime::currentTime()));
 
+    int frameRadius = DStyle::pixelMetric(style(), DStyle::PM_FrameRadius);
+    int margins = DStyle::pixelMetric(style(), DStyle::PM_FrameMargins);
     viewport()->setAutoFillBackground(false);
     viewport()->setAccessibleName("DCrumbViewport");
     setFrameShape(QFrame::NoFrame);
+    int margin = frameRadius / 2 + margins + 2;
+    setViewportMargins(margin, margin, margin, margin);
 
     d->widgetTop->setFixedWidth(1);
     d->widgetBottom->setFixedWidth(1);
@@ -940,6 +976,7 @@ void DCrumbEdit::setCrumbRadius(int crumbRadius)
     D_D(DCrumbEdit);
 
     d->crumbRadius = crumbRadius;
+    d->explicitCrumbRadius = true;
 }
 
 /*!
@@ -975,6 +1012,30 @@ bool DCrumbEdit::event(QEvent *e)
         d->widgetBottom->setFixedHeight(frame_radius);
         d->widgetLeft->setFixedWidth(frame_radius);
         d->widgetRight->setFixedWidth(frame_radius);
+    } else if (e->type() == QEvent::Resize) {
+        d->panelFrame->resize(size());
+    } else if (e->type() == QEvent::StyleChange)  {
+        int frameRadius = DStyle::pixelMetric(style(), DStyle::PM_FrameRadius);
+        // update crumbRadius if not set.
+        if (!d->explicitCrumbRadius) {
+            d->crumbRadius = frameRadius;
+            auto collection = document()->docHandle()->formatCollection();
+            for (int i = 0; i < collection->numFormats(); ++i) {
+                // only update format in d->formats.
+                if (!collection->format(i).hasProperty(QTextFormat::UserProperty + 1))
+                    continue;
+                const auto key = collection->format(i).property(QTextFormat::UserProperty + 1).toString();
+                if (d->formats.contains(key))
+                    collection->formats[i].setProperty(QTextFormat::UserProperty + 4, crumbRadius());
+            }
+            for (auto iter = d->formats.begin(); iter != d->formats.end(); iter++) {
+                iter->setBackgroundRadius(crumbRadius());
+            }
+        }
+
+        int margins = DStyle::pixelMetric(style(), DStyle::PM_FrameMargins);
+        int margin = frameRadius / 2 + margins + 2;
+        setViewportMargins(margin, margin, margin, margin);
     }
 
     return QTextEdit::event(e);
@@ -983,13 +1044,6 @@ bool DCrumbEdit::event(QEvent *e)
 /*!\reimp */
 void DCrumbEdit::paintEvent(QPaintEvent *event)
 {
-    QPainter p(viewport());
-
-    QStyleOptionFrame panel;
-    initStyleOption(&panel);
-    panel.rect = viewport()->rect();
-    style()->drawPrimitive(QStyle::PE_PanelLineEdit, &panel, &p, this);
-
     QTextEdit::paintEvent(event);
 }
 
