@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include <DHorizontalLine>
 
@@ -41,6 +28,7 @@
 #include "dtitlebar.h"
 #include "dwarningbutton.h"
 #include "dsuggestbutton.h"
+#include "dsizemode.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
@@ -271,45 +259,32 @@ void DDialogPrivate::_q_defaultButtonTriggered()
 }
 
 /*!
-    \~chinese \class DDialog
-    \~chinese \brief 可以使用 DDialog 类快速创建符合 DDE 风格的简要对话框窗口。
+@~english
+    @class Dtk::Widget::DDialog
+    \inmodule dtkwidget
 
-    \~chinese \ingroup dialog-classes
-    \~chinese \ingroup abstractwidgets
+    @brief Use DDialog class to create quick dialog window matched DDE style.
 
-    \~chinese DDialog 旨在提供简要的讯问式对话框的快速实现。提供了包含标题，对话框内容，默认图标，用以添加按钮的布局和一个可以自由添加内容的内容布局。
-    可以使用 addButton() , insertButton(), setDefaultButton() 等函数方便的给对话框插入按钮并进行管理，可以使用 addContent(), insertContent()
-    等函数操作内容布局。
+    @ingroup dialog-classes
+    @ingroup abstractwidgets
 
-    \~chinese 此外， DDialog 还提供了一些额外的函数以供实现一些常见的需求。如，可以通过设置 setOnButtonClickedClose() 为 true 来使得用
-    户在点击任何对话框上的按钮后关闭对话框。
+    \section1 differences Differences with QDialog
 
-    \~chinese 当你需要快速构建较为简单结构的对话框，你应当使用 DDialog ，对于较为复杂的需求，请参阅 DAbstractDialog 或 QDialog 相关文档。
-
-    \~chinese \sa DAbstractDialog, QDialog
-*/
-
-/*!
-    \~english \class DDialog
-    \~english \brief Use DDialog class to create quick dialog window matched DDE style.
-
-    \~english \ingroup dialog-classes
-    \~english \ingroup abstractwidgets
-
-    \~english \section differences Differences with QDialog
-
-    \~english DDialog is designed to provide a easy way to create information dialog which include title, dialog content,
+    DDialog is designed to provide a easy way to create information dialog which include title, dialog content,
     dialog icon, buttons. You can use addButton() , insertButton() and related functions to insert buttons to the dialog
     easily, and use addContent(), insertContent() and related functions to manage the dialog's built-in content layout.
 
-    \~english DDialog also provided some extra function which maybe useful for some common use case, for example, you can
+    DDialog also provided some extra function which maybe useful for some common use case, for example, you can
     set setOnButtonClickedClose() to \c true , then once user clicked a button, the dialog will got closed.
 
-    \~english \sa DAbstractDialog, QDialog
+    @sa DAbstractDialog, QDialog
 */
 
 /*!
- * \~chinese \brief 构造一个 DDialog 对话框。
+@~english
+  @brief Construct a DDialog dialog box
+
+  \a parent Parent control pointer
  */
 DDialog::DDialog(QWidget *parent) :
     DAbstractDialog(*new DDialogPrivate(this), parent)
@@ -318,11 +293,12 @@ DDialog::DDialog(QWidget *parent) :
 }
 
 /*!
- * \~chinese \brief 构造一个 DDialog 对话框。
- *
- * \~chinese \param title 标题
- * \~chinese \param message 对话框消息
- * \~chinese \param parent 父控件
+@~english
+  @brief Construct a DDialog dialog box
+  
+  \a title Title
+  \a message Dialog box messages
+  \a parent Parent control pointer
  */
 DDialog::DDialog(const QString &title, const QString &message, QWidget *parent) :
     DAbstractDialog(*new DDialogPrivate(this), parent)
@@ -334,11 +310,12 @@ DDialog::DDialog(const QString &title, const QString &message, QWidget *parent)
 }
 
 /*!
- * \~chinese \brief 通过按钮文字获取按钮下标
- *
- * \~chinese \param text 按钮文字
- *
- * \~chinese \return 按钮下标
+@~english
+  @brief Gets the button index from its text
+  
+  \a text The text of the button
+  
+  @return The index of the button
  */
 int DDialog::getButtonIndexByText(const QString &text) const
 {
@@ -355,7 +332,8 @@ int DDialog::getButtonIndexByText(const QString &text) const
 }
 
 /*!
- * \~chinese \brief 获得对话框包含的按钮数量
+@~english
+  @brief Gets the number of buttons that the dialog box contains.
  */
 int DDialog::buttonCount() const
 {
@@ -365,7 +343,8 @@ int DDialog::buttonCount() const
 }
 
 /*!
- * \~chinese \brief 获得对话框所含的所有内容控件的数量
+@~english
+  @brief Gets the number of all content controls that the dialog box contains.
  */
 int DDialog::contentCount() const
 {
@@ -375,7 +354,8 @@ int DDialog::contentCount() const
 }
 
 /*!
- * \~chinese \brief 获得对话框的按钮列表
+@~english
+  @brief Gets a list of buttons for the dialog box
  */
 QList<QAbstractButton *> DDialog::getButtons() const
 {
@@ -385,7 +365,8 @@ QList<QAbstractButton *> DDialog::getButtons() const
 }
 
 /*!
- * \~chinese \brief 获得对话框所含的所有内容控件列表
+@~english
+  @brief Gets a list of all content controls that the dialog box contains
  */
 QList<QWidget *> DDialog::getContents() const
 {
@@ -395,10 +376,11 @@ QList<QWidget *> DDialog::getContents() const
 }
 
 /*!
- * \~chinese \brief 获得指定下标所对应的按钮
- *
- * \~chinese \param index 按钮下标
- * \~chinese \return 对应的按钮
+@~english
+  @brief Gets the button corresponding to the specified index
+  
+  \a index The index of the button
+  @return Returns the button with the specified index
  */
 QAbstractButton *DDialog::getButton(int index) const
 {
@@ -408,9 +390,10 @@ QAbstractButton *DDialog::getButton(int index) const
 }
 
 /*!
- * \~chinese \brief DDialog::getContent 获取指定下标对应的内容控件
- * \~chinese \param index　控件下标
- * \~chinese \return 返回对应的内容控件
+@~english
+  @brief Gets the content control corresponding to the specified subscript
+  \a index The index of the control
+  @return Returns the corresponding content control
  */
 QWidget *DDialog::getContent(int index) const
 {
@@ -420,8 +403,10 @@ QWidget *DDialog::getContent(int index) const
 }
 
 /*!
- * \~chinese \brief DDialog::title
- * \~chinese \return 返回对话框的标题内容
+@~english
+  @brief Returns the dialog box title
+
+  @return Returns the dialog box title
  */
 QString DDialog::title() const
 {
@@ -431,8 +416,10 @@ QString DDialog::title() const
 }
 
 /*!
- * \~chinese \brief DDialog::message
- * \~chinese \return 返回对话框的显示信息
+@~english
+  @brief Returns the dialog box message text.
+
+  @return Returns the dialog box message text
  */
 QString DDialog::message() const
 {
@@ -442,8 +429,10 @@ QString DDialog::message() const
 }
 
 /*!
- * \~chinese \brief DDialog::icon
- * \~chinese \return  返回对话框的icon
+@~english
+  @brief Return to the dialog box icon
+
+  @return  Return to the dialog box icon
  */
 QIcon DDialog::icon() const
 {
@@ -453,8 +442,9 @@ QIcon DDialog::icon() const
 }
 
 /*!
- * \~chinese \brief DDialog::iconPixmap
- * \~chinese \return 返回ICON的pixmap
+@~english
+  @brief Returns the QPixmap object of the dialog icon
+  @return Returns the QPixmap object of the dialog icon
  */
 QPixmap DDialog::iconPixmap() const
 {
@@ -468,8 +458,10 @@ QPixmap DDialog::iconPixmap() const
 }
 
 /*!
- * \~chinese \brief DDialog::textFormat
- * \~chinese \return 返回设定的文本格式
+@~english
+  @brief Returns the text format of the dialog box
+
+  @return Returns the text format of the dialog box
  */
 Qt::TextFormat DDialog::textFormat() const
 {
@@ -479,7 +471,10 @@ Qt::TextFormat DDialog::textFormat() const
 }
 
 /*!
- * \~chinese \brief 检查在点击任何按钮后是否都会关闭对话框。
+@~english
+  @brief Check to see if the dialog closes after clicking any button
+
+  @return Returns true if the dialog box is closed, false otherwise
  */
 bool DDialog::onButtonClickedClose() const
 {
@@ -489,8 +484,9 @@ bool DDialog::onButtonClickedClose() const
 }
 
 /*!
- * \~chinese \brief DDialog::setContentLayoutContentsMargins 设定内容布局的内容margin
- * \~chinese \param margins 具体的margins
+@~english
+  @brief Sets the content margin for the content layout
+  \a margins Specific margins
  */
 void DDialog::setContentLayoutContentsMargins(const QMargins &margins)
 {
@@ -500,8 +496,10 @@ void DDialog::setContentLayoutContentsMargins(const QMargins &margins)
 }
 
 /*!
- * \~chinese \brief DDialog::contentLayoutContentsMargins
- * \~chinese \return 返回内容布局的内容margin
+@~english
+  @brief Returns the margins for the content layout
+
+  @return Returns the content margin of the content layout
  */
 QMargins DDialog::contentLayoutContentsMargins() const
 {
@@ -511,8 +509,10 @@ QMargins DDialog::contentLayoutContentsMargins() const
 }
 
 /*!
- * \~chinese \brief DDialog::closeButtonVisible
- * \~chinese \return 返回关闭按钮是否可见的bool值
+@~english
+  @brief Turns off the visibility property of the button
+
+  @return Returns the bool value of whether the close button is visible
  */
 bool DDialog::closeButtonVisible() const
 {
@@ -520,13 +520,14 @@ bool DDialog::closeButtonVisible() const
 }
 
 /*!
- * \~chinese \brief 向对话框添加按钮
- *
- * \~chinese \param text 按钮文字
- * \~chinese \param isDefault 是否默认按钮
- * \~chinese \param type 按钮类型
- *
- * \~chinese \return 所添加的按钮的下标
+@~english
+  @brief Adds a button to the dialog box
+  
+  \a text The text of button
+  \a isDefault Default button or not
+  \a type Types of button
+  
+  @return The index of the added button
  */
 int DDialog::addButton(const QString &text, bool isDefault, ButtonType type)
 {
@@ -538,11 +539,12 @@ int DDialog::addButton(const QString &text, bool isDefault, ButtonType type)
 }
 
 /*!
- * \~chinese \brief 向对话框添加按钮
- *
- * \~chinese \param text 按钮文字
- *
- * \~chinese \return 所添加的按钮的下标
+@~english
+  @brief Adds a button to the dialog box
+  
+  \a text The text of button
+  
+  @return The index of the added button
  */
 int DDialog::addButtons(const QStringList &text)
 {
@@ -554,12 +556,13 @@ int DDialog::addButtons(const QStringList &text)
 }
 
 /*!
- * \~chinese \brief 向对话框插入按钮
- *
- * \~chinese \param index 下标
- * \~chinese \param text 按钮文字
- * \~chinese \param isDefault 是否是默认按钮
- * \~chinese \param type 按钮类型
+@~english
+  @brief Adds a button to the dialog box
+  
+  \a index The index of the button to add
+  \a text The text of button
+  \a isDefault Default button or not
+  \a type Types of buttons
  */
 void DDialog::insertButton(int index, const QString &text, bool isDefault, ButtonType type)
 {
@@ -586,11 +589,12 @@ void DDialog::insertButton(int index, const QString &text, bool isDefault, Butto
 }
 
 /*!
- * \~chinese \brief 向对话框插入按钮
- *
- * \~chinese \param index 下标
- * \~chinese \param button 待插入的按钮
- * \~chinese \param isDefault 是否是默认按钮
+@~english
+  @brief Inserts a button into the dialog box.
+  
+  \a index The index of the button to add
+  \a button Button to insert
+  \a isDefault Default button or not
  */
 void DDialog::insertButton(int index, QAbstractButton *button, bool isDefault)
 {
@@ -598,7 +602,7 @@ void DDialog::insertButton(int index, QAbstractButton *button, bool isDefault)
 
     DVerticalLine *line = new DVerticalLine;
     line->setObjectName("VLine");
-    line->setFixedHeight(30);
+    line->setFixedHeight(DSizeModeHelper::element(20, 30));
 
     d->buttonLayout->insertWidget(index * 2 , line);
     d->buttonLayout->insertWidget(index * 2 + 1, button);
@@ -636,10 +640,11 @@ void DDialog::insertButton(int index, QAbstractButton *button, bool isDefault)
 }
 
 /*!
- * \~chinese \brief 向对话框插入按钮
- *
- * \~chinese \param index 下标
- * \~chinese \param text 按钮文字
+@~english
+  @brief Inserts a button into the dialog box
+  
+  \a index The index of the button to add
+  \a text The text of button
  */
 void DDialog::insertButtons(int index, const QStringList &text)
 {
@@ -649,9 +654,10 @@ void DDialog::insertButtons(int index, const QStringList &text)
 }
 
 /*!
- * \~chinese \brief 从对话框移除按钮
- *
- * \~chinese \param index 待移除按钮的下标
+@~english
+  @brief Removes the button from the dialog box
+  
+  \a index The index of the button to remove
  */
 void DDialog::removeButton(int index)
 {
@@ -685,9 +691,10 @@ void DDialog::removeButton(int index)
 }
 
 /*!
- * \~chinese \brief 从对话框移除按钮
- *
- * \~chinese \param button 待移除的按钮
+@~english
+  @brief Removes the button from the dialog box
+  
+  \a button The button to remove
  */
 void DDialog::removeButton(QAbstractButton *button)
 {
@@ -695,9 +702,10 @@ void DDialog::removeButton(QAbstractButton *button)
 }
 
 /*!
- * \~chinese \brief 从对话框移除按钮
- *
- * \~chinese \param text 待移除按钮的文本内容
+@~english
+  @brief Removes the button from the dialog box
+  
+  \a text The text of the button to remove
  */
 void DDialog::removeButtonByText(const QString &text)
 {
@@ -708,7 +716,8 @@ void DDialog::removeButtonByText(const QString &text)
 }
 
 /*!
- * \~chinese \brief 清除所有按钮
+@~english
+  @brief Clear all buttons
  */
 void DDialog::clearButtons()
 {
@@ -726,11 +735,11 @@ void DDialog::clearButtons()
 }
 
 /*!
- * \~chinese \brief 设置默认按钮
- *
- * \~chinese \param index 要设置的默认按钮的下标
- *
- * \~chinese \sa \ref default "默认按钮"
+@~english
+  @brief Setting the default button
+  
+  \a index The index of the default button to set
+  @return Returns true on success and false otherwise
  */
 bool DDialog::setDefaultButton(int index)
 {
@@ -743,11 +752,11 @@ bool DDialog::setDefaultButton(int index)
 }
 
 /*!
- * \~chinese \brief 设置默认按钮
- *
- * \~chinese \param str 要设置的默认按钮的文本内容
- *
- * \sa \ref default "默认按钮"
+@~english
+  @brief Setting the default button
+  
+  \a str The text content of the default button to set
+  @sa default
  */
 bool DDialog::setDefaultButton(const QString &str)
 {
@@ -755,11 +764,11 @@ bool DDialog::setDefaultButton(const QString &str)
 }
 
 /*!
- * \~chinese \brief 设置默认按钮
- *
- * \~chinese \param button 要设置的默认按钮
- *
- * \sa \ref default "默认按钮"
+@~english
+  @brief Setting the default button
+  
+  \a button Default button to set
+  @sa default
  */
 void DDialog::setDefaultButton(QAbstractButton *button)
 {
@@ -769,10 +778,11 @@ void DDialog::setDefaultButton(QAbstractButton *button)
 }
 
 /*!
- * \~chinese \brief 添加控件到对话框内容布局
- *
- * \~chinese \param widget 待添加的控件
- * \~chinese \param alignment 对齐方式
+@~english
+  @brief Add controls to the dialog content layout.
+  
+  \a widget Controls to add
+  \a alignment alignment
  */
 void DDialog::addContent(QWidget *widget, Qt::Alignment alignment)
 {
@@ -784,11 +794,12 @@ void DDialog::addContent(QWidget *widget, Qt::Alignment alignment)
 }
 
 /*!
- * \~chinese \brief 在对话框内容布局指定位置插入控件
- *
- * \~chinese \param index 待插入的位置下标
- * \~chinese \param widget 待插入的控件
- * \~chinese \param alignment 对齐方式
+@~english
+  @brief Inserts a control at the location specified in the dialog box content layout
+  
+  \a index The index of the position to insert
+  \a widget Control to insert
+  \a alignment alignment
  */
 void DDialog::insertContent(int index, QWidget *widget, Qt::Alignment alignment)
 {
@@ -800,10 +811,11 @@ void DDialog::insertContent(int index, QWidget *widget, Qt::Alignment alignment)
 }
 
 /*!
- * \~chinese \brief 从对话框内容布局中移除指定控件
- *
- * \~chinese \param widget 待移除的控件
- * \~chinese \param isDelete 是否执行删除
+@~english
+  @brief Removes the specified control from the dialog box content layout.
+  
+  \a widget Control to remove
+  \a isDelete Whether to delete
  */
 void DDialog::removeContent(QWidget *widget, bool isDelete)
 {
@@ -818,9 +830,10 @@ void DDialog::removeContent(QWidget *widget, bool isDelete)
 }
 
 /*!
- * \~chinese \brief 清空对话框内容布局中的所有内容
- *
- * \~chinese \param isDelete 是否删除
+@~english
+  @brief Clear everything in the content layout of the dialog box.
+  
+  \a isDelete Whether to delete
  */
 void DDialog::clearContents(bool isDelete)
 {
@@ -837,11 +850,12 @@ void DDialog::clearContents(bool isDelete)
 }
 
 /*!
- * \~chinese \brief 设置对话框内容间隔
- *
- * \~chinese 设置对话框的内容布局的间隔大小
- *
- * \sa QBoxLayout::setSpacing
+@~english
+  @brief Sets the dialog content interval.
+  
+  \a spacing Spacing size for the content layout of the dialog box
+  
+  @sa QBoxLayout::setSpacing
  */
 void DDialog::setSpacing(int spacing)
 {
@@ -851,11 +865,12 @@ void DDialog::setSpacing(int spacing)
 }
 
 /*!
- * \~chinese \brief 追加对话框内容间隔
- *
- * \~chinese 在对话框的内容布局后追加一个非弹性，大小为 \a spacing 的间隔（一个 QSpacerItem ）。
- *
- * \sa QBoxLayout::addSpacing
+@~english
+  @brief Append dialog box content intervals
+  
+  Append an inelastic interval of size \a spacing after the content layout of the dialog box (a QSpacerItem)
+  
+  @sa QBoxLayout::addSpacing
  */
 void DDialog::addSpacing(int spacing)
 {
@@ -865,11 +880,13 @@ void DDialog::addSpacing(int spacing)
 }
 
 /*!
- * \~chinese \brief 插入对话框内容间隔
- *
- * \~chinese 在对话框的内容布局的指定位置插入一个非弹性，大小为 \a spacing 的间隔（一个 QSpacerItem ）。
- *
- * \sa QBoxLayout::insertSpacing
+@~english
+  @brief Insert dialog box content intervals.
+  
+  Inserts an inelastic interval of size spacing (a QSpacerItem) at the specified position in the content layout of the dialog box.
+  \a index The index position at which the interval is inserted.
+  
+  @sa QBoxLayout::insertSpacing
  */
 void DDialog::insertSpacing(int index, int spacing)
 {
@@ -879,9 +896,10 @@ void DDialog::insertSpacing(int index, int spacing)
 }
 
 /*!
- * \~chinese \brief 清除内容间隔
- *
- * \~chinese 清除对话框内容布局中包含的所有 QSpacerItem 。
+@~english
+  @brief Clear content intervals.
+  
+  Clear all QSpacerItems contained in the dialog content layout.
  */
 void DDialog::clearSpacing()
 {
@@ -897,10 +915,11 @@ void DDialog::clearSpacing()
 }
 
 /*!
- * \~chinese \brief 设置按钮文字
- *
- * \~chinese \param index 需要设置文字的按钮的下标
- * \~chinese \param text 所需要设置的文字
+@~english
+  @brief Setting button text.
+  
+  \a index The index of the button that requires the text to be set
+  \a text Text to set
  */
 void DDialog::setButtonText(int index, const QString &text)
 {
@@ -910,9 +929,10 @@ void DDialog::setButtonText(int index, const QString &text)
 }
 
 /*!
- * \~chinese \brief 设置按钮图标
- * \~chinese \param index 需要设置图标的按钮的下标
- * \~chinese \param icon 所需要设置的图标
+@~english
+  @brief Set button icon.
+  \a index The index of the button that needs to be set for the icon
+  \a icon Icon to set
  */
 void DDialog::setButtonIcon(int index, const QIcon &icon)
 {
@@ -922,7 +942,10 @@ void DDialog::setButtonIcon(int index, const QIcon &icon)
 }
 
 /*!
- * \~chinese \brief 设置对话框标题
+@~english
+  @brief Sets the dialog box title.
+
+  \a title Dialog box title.
  */
 void DDialog::setTitle(const QString &title)
 {
@@ -939,8 +962,10 @@ void DDialog::setTitle(const QString &title)
 }
 
 /*!
- * \~chinese \brief DDialog::setWordWrapTitle 设定标题Label内容是否可截断换行
- * \~chinese \param wordWrap true可换行　false不可以换行
+@~english
+  @brief Specifies whether the content of the title Label can be truncated.
+
+  \a wordWrap true can wrap a line. false can't wrap a line
  */
 void DDialog::setWordWrapTitle(bool wordWrap)
 {
@@ -949,7 +974,10 @@ void DDialog::setWordWrapTitle(bool wordWrap)
 }
 
 /*!
- * \~chinese \brief 设置对话框消息内容
+@~english
+  @brief Sets the dialog box message content.
+
+  \a message Dialog box messages
  */
 void DDialog::setMessage(const QString &message)
 {
@@ -972,7 +1000,9 @@ void DDialog::setWordWrapMessage(bool wordWrap)
 }
 
 /*!
- * \~chinese \brief 设置对话框图标
+@~english
+  @brief Set the dialog icon
+  \a icon Dialog icon
  */
 void DDialog::setIcon(const QIcon &icon)
 {
@@ -986,9 +1016,13 @@ void DDialog::setIcon(const QIcon &icon)
 }
 
 /*!
- * \~chinese \brief 设置对话框图标
- *
- * \~chinese 为对话框设置图标，同时可以指定一个期望的图标大小。
+@~english
+  @brief Set the dialog icon.
+  \overload
+
+  Sets the icon for the dialog box and specifies a desired icon size.
+
+  \a icon Dialog icon \a expectedSize Expected size.
  */
 void DDialog::setIcon(const QIcon &icon, const QSize &expectedSize)
 {
@@ -1006,7 +1040,10 @@ void DDialog::setIcon(const QIcon &icon, const QSize &expectedSize)
 }
 
 /*!
- * \~chinese \brief 设置对话框位图图标
+@~english
+  @brief Sets the dialog box bitmap icon.
+
+  \a iconPixmap icon of pixmap type.
  */
 void DDialog::setIconPixmap(const QPixmap &iconPixmap)
 {
@@ -1014,7 +1051,9 @@ void DDialog::setIconPixmap(const QPixmap &iconPixmap)
 }
 
 /*!
- * \~chinese \brief 设置文字格式
+@~english
+  @brief Formatting text.
+  \a textFormat Text format.
  */
 void DDialog::setTextFormat(Qt::TextFormat textFormat)
 {
@@ -1031,9 +1070,10 @@ void DDialog::setTextFormat(Qt::TextFormat textFormat)
 }
 
 /*!
- * \~chinese \brief 设置是否在点击按钮后关闭对话框
- *
- * \~chinese 当设置为 true 后，无论点击什么按钮，都会在点击后关闭对话框。
+@~english
+  @brief Sets whether to close the dialog box when the button is clicked.
+  
+  When \a onButtonClickedClose is set to true, whatever button is clicked will close the dialog box when clicked.
  */
 void DDialog::setOnButtonClickedClose(bool onButtonClickedClose)
 {
@@ -1043,12 +1083,15 @@ void DDialog::setOnButtonClickedClose(bool onButtonClickedClose)
 }
 
 /*!
- * \~chinese \brief 以模态框形式显示当前对话框
- *
- * \~chinese 以 \l{QDialog#Modal Dialogs}{模态框} 形式显示当前对话框，将会阻塞直到用户关闭对话框。
- *
- * \~chinese onButtonClickedClose()为 true 时返回当前点击按钮的Index，否则返回 \DialogCode 结果。
- *
+@~english
+  @brief Displays the current dialog box as a modal.
+  
+  Displaying the current dialog as {QDialog#Modal Dialogs}{modal boxes} will block until the user closes the dialog box.
+  
+  If \a onButtonClickedClose() is true, it returns the Index of the button that is currently clicked; otherwise, it returns the result.
+  @return Returns the result of the modal dialog processing.
+
+  @sa QDialog::exec()
  */
 int DDialog::exec()
 {
@@ -1167,6 +1210,20 @@ bool DDialog::eventFilter(QObject *watched, QEvent *event)
     return DAbstractDialog::eventFilter(watched, event);
 }
 
+void DDialog::changeEvent(QEvent *event)
+{
+    Q_D(DDialog);
+    if (event->type() == QEvent::StyleChange) {
+        for (int i = 0; i < d->buttonLayout->count(); ++i) {
+            if (auto line = qobject_cast<DVerticalLine *>(d->buttonLayout->itemAt(i)->widget())) {
+                line->setFixedHeight(DSizeModeHelper::element(20, 30));
+            }
+        }
+        d->updateSize();
+    }
+    return DAbstractDialog::changeEvent(event);
+}
+
 DWIDGET_END_NAMESPACE
 
 #include "moc_ddialog.cpp"
