@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "dspinner.h"
 
 #include <QtMath>
@@ -35,25 +39,22 @@ DSpinnerPrivate::DSpinnerPrivate(DSpinner *qq)
 }
 
 /*!
+@~english
     \class Dtk::Widget::DSpinner
     \inmodule dtkwidget
 
-    \brief 可以使用 DSpinner 类快速创建用于指示加载中状态的旋转等待图标动画控件.
-
-    DSpinner 提供了一个用于指示加载中状态的旋转等待图标动画控件。在创建图标后，使用 start() 即可开始图标旋转的动画。
     \brief Use DSpinner to create a widget with spinning animation for display a waiting state.
     DSpinner provide a spinning animation widget to indicate a waiting state. Call start() to start
     the spinning animation.
 
-    \image DSpinner.gif
+    \image html DSpinner.gif
 */
 
 /*!
+@~english
   \brief Create a DSpinner widget
-  \brief 创建一个 DSpinner 控件
   
   \a parent Parent widget.
-  \a parent 父控件
  */
 DSpinner::DSpinner(QWidget *parent) :
     QWidget(parent), DObject(*new DSpinnerPrivate(this))
@@ -76,10 +77,10 @@ DSpinner::~DSpinner()
 }
 
 /*!
+@~english
   \brief Is the DSpinner spinning or not.
-  \brief DSpinner 是否正在播放旋转动画.
 
-  \return 正在播放返回 true，否则返回 false.
+  \return DSpinner is spinning and returns true, otherwise returns false
  */
 bool DSpinner::isPlaying() const
 {
@@ -88,8 +89,8 @@ bool DSpinner::isPlaying() const
 }
 
 /*!
+@~english
   \brief Start spinning
-  \brief 开始旋转动画
  */
 void DSpinner::start()
 {
@@ -98,8 +99,8 @@ void DSpinner::start()
 }
 
 /*!
+@~english
   \brief Stop spinning
-  \brief 停止旋转动画
  */
 void DSpinner::stop()
 {
@@ -108,8 +109,8 @@ void DSpinner::stop()
 }
 
 /*!
-  \brief Set background \a color
-  \brief 设置背景颜色
+@~english
+  \brief Set background \a color Color to be set
  */
 void DSpinner::setBackgroundColor(QColor color)
 {
