@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dswitchlineexpand.h"
 #include "dthememanager.h"
@@ -72,7 +59,7 @@ void DSwitchHeaderLine::mousePressEvent(QMouseEvent *)
   控件由标题栏和内容两部分组成，标题栏左侧显示控件标题，右侧显示一个开关控件，
   用户通过点击右侧的开关控件，来控制标题栏下面的内容部分展开还是合上。
   
-  \image switchlineexpand.png
+  \image html switchlineexpand.png
  */
 
 /*!
