@@ -64,6 +64,10 @@ public:
     QString appDescription;
     QString homePage;
     QString acknowledgementPage;
+    QString applicationCreditsFile;
+    QByteArray applicationCreditsContent;
+    QString licensePath;
+
     bool acknowledgementPageVisible = true;
 
     bool visibleMenuShortcutText   = false;
@@ -74,6 +78,7 @@ public:
     DAppHandler *appHandler = Q_NULLPTR;
     DAboutDialog *aboutDialog = Q_NULLPTR;
     DFeatureDisplayDialog *featureDisplayDialog = Q_NULLPTR;
+    DLicenseDialog *licenseDialog = Q_NULLPTR;
 
     // 需要自适应虚拟键盘环境的窗口
     QPointer<QWidget> activeInputWindow;
